.. AUTO-GENERATED FILE -- DO NOT EDIT!

Module: :mod:`display`
======================
.. automodule:: IPython.display

.. currentmodule:: IPython.display

23 Classes
----------

.. autoclass:: Audio
  :members:
  :show-inheritance:

  .. automethod:: __init__

.. autoclass:: Code
  :members:
  :show-inheritance:

  .. automethod:: __init__

.. autoclass:: DisplayHandle
  :members:
  :show-inheritance:

  .. automethod:: __init__

.. autoclass:: DisplayObject
  :members:
  :show-inheritance:

  .. automethod:: __init__

.. autoclass:: FileLink
  :members:
  :show-inheritance:

  .. automethod:: __init__

.. autoclass:: FileLinks
  :members:
  :show-inheritance:

  .. automethod:: __init__

.. autoclass:: GeoJSON
  :members:
  :show-inheritance:

  .. automethod:: __init__

.. autoclass:: HTML
  :members:
  :show-inheritance:

  .. automethod:: __init__

.. autoclass:: IFrame
  :members:
  :show-inheritance:

  .. automethod:: __init__

.. autoclass:: Image
  :members:
  :show-inheritance:

  .. automethod:: __init__

.. autoclass:: JSON
  :members:
  :show-inheritance:

  .. automethod:: __init__

.. autoclass:: Javascript
  :members:
  :show-inheritance:

  .. automethod:: __init__

.. autoclass:: Latex
  :members:
  :show-inheritance:

.. autoclass:: Markdown
  :members:
  :show-inheritance:

.. autoclass:: Math
  :members:
  :show-inheritance:

.. autoclass:: Pretty
  :members:
  :show-inheritance:

.. autoclass:: ProgressBar
  :members:
  :show-inheritance:

  .. automethod:: __init__

.. autoclass:: SVG
  :members:
  :show-inheritance:

.. autoclass:: ScribdDocument
  :members:
  :show-inheritance:

  .. automethod:: __init__

.. autoclass:: TextDisplayObject
  :members:
  :show-inheritance:

.. autoclass:: Video
  :members:
  :show-inheritance:

  .. automethod:: __init__

.. autoclass:: VimeoVideo
  :members:
  :show-inheritance:

  .. automethod:: __init__

.. autoclass:: YouTubeVideo
  :members:
  :show-inheritance:

  .. automethod:: __init__

16 Functions
------------

.. autofunction:: IPython.display.clear_output


.. autofunction:: IPython.display.display


.. autofunction:: IPython.display.display_html


.. autofunction:: IPython.display.display_javascript


.. autofunction:: IPython.display.display_jpeg


.. autofunction:: IPython.display.display_json


.. autofunction:: IPython.display.display_latex


.. autofunction:: IPython.display.display_markdown


.. autofunction:: IPython.display.display_pdf


.. autofunction:: IPython.display.display_png


.. autofunction:: IPython.display.display_pretty


.. autofunction:: IPython.display.display_svg


.. autofunction:: IPython.display.publish_display_data


.. autofunction:: IPython.display.set_matplotlib_close


.. autofunction:: IPython.display.set_matplotlib_formats


.. autofunction:: IPython.display.update_display

